<template>
  <SlideOver
    :parent-route="{ name: 'links' }"
    route
    size="full"
  >
    <SlideOverHeader>
      <SlideOverTitle>{{ $t("app.links.analytics.title") }}</SlideOverTitle>
      <div>
        <FormDate
          v-model="filters.date"
          name="date"
          range
          required
        />
      </div>
    </SlideOverHeader>
    <SlideOverBody>
      <template v-if="linkFetch.isFetching">
        <transition :duration="100">
          <template v-if="linkFetch.isFetching">
            <div class="absolute z-20 flex h-full w-full rounded bg-white">
              <CircleNotchSolidIcon class="mx-auto my-10 h-7 w-7 animate-spin fill-primary-500" />
            </div>
          </template>
        </transition>
      </template>
      <template v-else-if="linkFetch.hasErrors">
        <ErrorState />
      </template>
      <template v-else>
        <LinksAnalyticsCharts
          :filters="filters"
          :link="link"
        />
      </template>
    </SlideOverBody>
  </SlideOver>
</template>

<script lang="ts" setup>
import SlideOverBody from "@/js/contexts/shared/ui/components/slide-over/SlideOverBody.vue";
import SlideOverHeader from "@/js/contexts/shared/ui/components/slide-over/SlideOverHeader.vue";
import SlideOver from "@/js/contexts/shared/ui/components/slide-over/SlideOver.vue";
import SlideOverTitle from "@/js/contexts/shared/ui/components/slide-over/SlideOverTitle.vue";
import useFetch from "@/js/contexts/shared/composables/useFetch";
import type { Link } from "@/js/contexts/shared/models/Link";
import FormDate from "@/js/contexts/form/ui/components/FormDate.vue";
import useFilters from "@/js/contexts/shared/composables/useFilters";
import useDayjs from "@/js/contexts/shared/composables/useDayjs";
import type { LinkAnalyticsFilters } from "@/js/contexts/links/models/LinkAnalyticsFilters";
import ErrorState from "@/js/contexts/shared/ui/components/error/ErrorState.vue";
import CircleNotchSolidIcon from "@/svg/icons/circle-notch-solid.svg?component";
import LinksAnalyticsCharts from "@/js/contexts/links/ui/components/LinksAnalyticsCharts.vue";

const route = useRoute();
const link = ref<Link>();
const dayjs = useDayjs();

const filters = useFilters<LinkAnalyticsFilters>(
  {
    date: { start: dayjs().subtract(6, "days").startOf("day").toDate(), end: dayjs().endOf("day").toDate() },
  },
  ["date"],
);

const linkFetch = useFetch(`/api/links/${route.params.id}`, { isFetching: true });

onMounted(() => {
  linkFetch.get<Link>().then((response) => (link.value = response.data));
});
</script>
